#!/bin/zsh

if [ -z "$1" ]; then
	echo "$0 MUST get one argument and thats the module to build"
	exit 1
fi

mod=$1

if [ x$NO_KILLGCONF != xyes ]; then
	echo -----------------
	echo Following might just blow up, nothing to worry about
	echo Shutting down gconf-1...
	echo gconftool-1 --shutdown
	gconftool-1 --shutdown
	echo -----------------
	echo Shutting down gconf-2...
	echo gconftool-2 --shutdown
	gconftool-2 --shutdown
	echo -----------------
fi

if [ -z "$PREFIX" ]; then
	PREFIX=$HOME
fi

if [ ! -d "$PREFIX" ]; then
	if [ ! mkdir $PREFIX ]; then
		echo
		echo "ERROR: $PREFIX doesn't exist and we can't make it"
		echo
		exit 1
	fi
fi

if [ -z "$MODFILE" ]; then
	MODFILE=$HOME/bin/modules.sh
fi

if [ ! -e $MODFILE ]; then
	echo
	echo WARNING: $MODFILE not found
	echo
	exit 1
fi

echo cd $PREFIX/cvs
cd $PREFIX/cvs
source setvars.sh

echo -------------------------------------------------------------
echo Module: $mod
echo -------------------------------------------------------------

echo Checking for flags...
MODFLAGS=
if grep AUTOGEN_$mod $MODFILE ; then
	MODFLAGS=`grep AUTOGEN_$mod $MODFILE | sed -e 's/^[^:]*://'`
fi
MODCVSFLAGS=
if grep CVSFLAGS_$mod $MODFILE ; then
	MODCVSFLAGS=`grep CVSFLAGS_$mod $MODFILE | sed -e 's/^[^:]*://'`
fi
MODCLEANFLAGS=
if grep CLEANFLAGS_$mod $MODFILE ; then
	MODCLEANFLAGS=`grep CLEANFLAGS_$mod $MODFILE | sed -e 's/^[^:]*://'`
fi


MODCLEAN=$CLEAN
echo cd $PREFIX/cvs
cd $PREFIX/cvs
if [ ! -d $mod ]; then
	if [ x$NO_NETWORK = xyes ]; then
		echo
		echo "ERROR:$mod: Module doesn't exist, and no network"
		echo
		exit 1
	fi
	echo "cvs -z3 co ${=MODCVSFLAGS} $mod"
	if ! cvs -z3 co ${=MODCVSFLAGS} $mod ; then
		echo
		echo ERROR:$mod: checking out $mod
		echo
		exit 1
	fi
	MODCLEAN=yes
	echo cd $PREFIX/cvs/$mod
	cd $PREFIX/cvs/$mod
else
	echo cd $PREFIX/cvs/$mod
	cd $PREFIX/cvs/$mod
	if [ -e CLEAN ]; then
		MODCLEAN=yes
		rm -f CLEAN
	fi
	if [ x$MODCLEAN = xyes ]; then
		echo make ${=MODCLEANFLAGS} distclean
		if ! make ${=MODCLEANFLAGS} distclean ; then
			echo WARNING:$mod: Cant make distclean before update
		fi
	fi
	if [ ! x$NO_NETWORK = xyes ]; then
		echo cvs -z3 update -dP ${=MODCVSFLAGS}
		if ! cvs -z3 update -dP ${=MODCVSFLAGS} ; then
			echo
			echo ERROR:$mod: updating $mod
			echo
			exit 1
		fi
	fi
fi

if [ x$MODCLEAN = xyes ]; then
	if [ -e Makefile ]; then
		echo make ${=MODCLEANFLAGS} distclean
		if ! make ${=MODCLEANFLAGS} distclean ; then
			echo
			echo ERROR:$mod: Cant make distclean
			echo
			exit 1
		fi
		echo rm -f config.cache
		rm -f config.cache
	fi
fi

#
# NO_BUILD=yes will make things not build but just check-out
#
if [ x$NO_BUILD = xyes ]; then
	exit 0
fi

if [ ! -e Makefile ]; then
	echo -----------------
	echo Configuring...
	echo ./autogen.sh --prefix=$PREFIX/foo ${=MODFLAGS}
	./autogen.sh --prefix=$PREFIX/foo ${=MODFLAGS}
	if [ ! -e Makefile ]; then
		echo
		echo ERROR:$mod: Cant autogen
		echo
		exit 1
	fi
fi

echo -----------------
echo Running make all

echo make all
if ! make all ; then
	echo
	echo WARNING:$mod: Cant make all
	echo
	echo rm -f Makefile
	rm -f Makefile
	echo rm -f config.cache
	rm -f config.cache
	echo -----------------
	echo Configuring
	echo ./autogen.sh --prefix=$PREFIX/foo ${=MODFLAGS}
	./autogen.sh --prefix=$PREFIX/foo ${=MODFLAGS}
	if [ ! -e Makefile ]; then
		echo
		echo ERROR:$mod: Cant autogen
		echo
		exit 1
	fi
	echo make all
	if ! make all ; then
		echo
		echo ERROR:$mod: Cant make all
		echo
		exit 1
	fi
fi

echo -----------------
echo Installing

echo make install
if ! make install ; then
	echo
	echo ERROR:$mod: Cant install
	echo
	exit 1
fi

if [ x$LEAN = xyes ]; then
	echo -----------------
	echo Lean clean
	echo make ${=MODCLEANFLAGS} clean
	make ${=MODCLEANFLAGS} clean
fi
