#!/bin/zsh

#
# Use following env variables:
#  STARTMODULE=<module>		start with this module
#  ENDMODULE=<module>		end with this module
#  CLEAN=yes 			"make distclean" before checking out and
#				building
#  LEAN=yes			after building "make clean"
#  NO_NETWORK=yes		never checkout/update from the network
#  NO_BUILD=yes			never build (useful to just check out all
#				modules quickly)
#  MODFILE=<modulefile>		alternative module file (default is
#				~/bin/modules.sh)
#  PREFIX=<prefix>		the prefix, by default "$HOME" installation
#				will be in $PREFIX/foo
#
#
# The different scripts are:
#   bootstrap.sh		bootstrap an environment, including pulling in
#				autoconf/automake/libtool/gettext
#   rebuild.sh			Rebuild all modules acording to the above
#				settings
#   modmake.sh <module>		Makes a single modules
#   modules.sh			Default module file, sourcable, sets the
#				MODULES var
#   packageenv.sh		Package an environment and scp it to my account
#

if [ -z "$PREFIX" ]; then
	PREFIX=$HOME
fi

if [ ! -d "$PREFIX" ]; then
	if [ ! mkdir $PREFIX ]; then
		echo
		echo "ERROR: $PREFIX doesn't exist and we can't make it"
		echo
		exit 1
	fi
fi


PRIV_STARTMODULE=$STARTMODULE

if [ -z "$MODFILE" ]; then
	MODFILE=$HOME/bin/modules.sh
fi

if [ ! -e $MODFILE ]; then
	echo
	echo WARNING: $MODFILE not found
	echo
	exit 1
fi

# Make sure it's in the environment
export MODFILE PREFIX

if [ ! -z "$MODULES" ]; then
	echo MODULES variable found, using that instead of sourcing $MODFILE
else
	echo source $MODFILE
	source $MODFILE
fi

echo cd $PREFIX/cvs
cd $PREFIX/cvs
echo source setvars.sh
source setvars.sh


for mod in ${=MODULES} ; do

	if [ x$ENDMODULE = x$mod ]; then
		echo
		echo Ending with $mod ...
		echo
		break
	fi
	
	if [ ! -z "$PRIV_STARTMODULE" ]; then
		if [ x$PRIV_STARTMODULE = x$mod ]; then
			PRIV_STARTMODULE=
		else
			echo Skipping $mod ...
			continue
		fi
	fi

	echo
	echo -----------------
	echo Running:
	echo $HOME/bin/modmake.sh $mod
	echo
	if ! $HOME/bin/modmake.sh $mod ; then
		echo
		echo Build failed on $mod
		echo
		exit 1
	fi

done

echo
echo -----------------
echo All done!
echo
